/*
 * Common structures used across various routines.
 *
 * Grisha Sitkarev, <sitkarev@unixkomi.ru>
 *
 */

#ifndef COMMON_H_
#define COMMON_H_

#include "complex.h"

enum filter_type {
	LOWPASS,
	HIGHPASS,
	BANDPASS,
	BANDSTOP,
	
};

enum filter_approx {
	BUTTERWORTH,
	CHEBYSHEV,
	ELLIPTIC,
};

/* Filter specification. */
struct filter_spec {
	enum filter_type	type;
	enum filter_approx	approx;
	unsigned int		order;
	double			atten_stop;
	double			atten_pass;
   	double			freq_pass1;
	double			freq_stop1;
	double           	freq_pass2;
	double			freq_stop2;
	double			k;
};

/* Representation of the transfer function of any plane. */
struct transfer_func {
	double			h_zero;		/* constant gain multiplier */
	unsigned int		np;		/* number of poles */
	unsigned int		nz;		/* number of zeros */
	complex_t		*poles;		/* poles of the transfer function */
	complex_t		*zeros;		/* zeros of the transfer function */
};


#endif

